@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20131227';
+our $VERSION = '0.20140131';
 
-# Table last modified: 2013-12-27
+# Table last modified: 2014-01-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -104,18 +104,18 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|5[06]|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[1589])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[0359])|101))',
-    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|8[124-8]|5[0-25]|3[0-289]|7[0-25-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|30|77|8[0-35]|2[45]|1[125689])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|5[0-259]|1[0-2478]|6[0135]|8[2457]|7[02358]|4[0-3578]|3[0-8]|2[124589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[02-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|8[4-689]|2[0-25]|5[24-68]|6[067]|3[13-8]|4[238]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
+    '101' => '(?:8(?:5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|3(?:6[2356]|0[1257-9]|4[5-7]|8[01358]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[0359])|101))',
+    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|8[124-8]|5[0-25]|3[0-289]|7[0-25-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:41|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:30|77|8[0-35]|2[45]|0[58]|1[125689])|79[58]))',
+    '103' => '(?:8(?:2(?:0[1-6]|5[0-259]|1[0-2478]|6[0135]|8[2457]|7[02358]|4[0-3578]|3[0-8]|2[124589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[02-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|8[4-689]|2[0-25]|6[67]|5[24-68]|3[13-8]|4[238]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-7])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|5(?:1[028]|3[0135689]|5[013-689]|4[0468]|7[02]|6[036-8]|2[0136-8]|0[1256]|8[014578])|3(?:7[027-9]|1[0-3579]|8[01368]|4[045]|2[014589]|5[167]|6[05]|3[02358]|0[2-59])|2(?:40|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-3]|3[2-7]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|1[0-24-69])|5(?:6[03578]|4[0356]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|7444))',
+    '105' => '(?:(?:8(?:4(?:7[0-3]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|3[02-7]|1[0-24-69])|5(?:6[03578]|4[0356]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|6[0-35-79]|7[136-8]|1[458]|4[13-5]|2[12]|3[1257]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|3[069])|0(?:[01]1|39)|401|797)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[07]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:20|34|56|77|0[134]|1[0-24679]|8[24]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
-    '108' => '(?:(?:8(?:5(?:7[1358]|1[0-25]|4[03-578]|5[0-35-9]|6[048]|3[0236]|0[12579]|2[035]|8[0-3568])|3(?:2[25689]|3[0348]|5[058]|8[0134689]|1[35]|6[01]|4[15]|7[02389]|0[3578])|2(?:7[056]|0[128]|8[02]|3[0-4]|5[05]|2[12]|4[0-2]|1[017])|4(?:[56]6|85|0[347]|3[09]|2[013-5]|7[078]|1[014-7]|4[48])|6(?:50|3[2356]|0[1267]|1[0-25-7]|2[28]|4[0-268])|0(?:[17]1|[25]0|8[08]|0[15])|7(?:1[03]|0[137])|117)|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:7[1358]|1[0-25]|4[03-578]|5[0-35-9]|6[048]|3[0236]|0[12579]|2[035]|8[0-3568])|3(?:2[25689]|3[0348]|5[058]|8[0134689]|1[35]|6[01]|4[15]|7[02389]|0[3578])|2(?:7[056]|0[128]|8[02]|3[0-4]|5[05]|2[12]|4[0-2]|1[017])|4(?:[56]6|85|0[3-57]|3[09]|2[013-5]|7[078]|1[014-7]|4[48])|6(?:50|3[2356]|0[1267]|1[0-25-7]|2[28]|4[0-268])|0(?:[17]1|[25]0|8[08]|0[15])|7(?:1[03]|0[137])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
-    '110' => '(?:8(?:5(?:8[2-468]|6[0-25-7]|5[0589]|4[013689]|7[5-8]|3[0-4679]|0[1-3579]|1[01357]|2[0-24])|6(?:97|2[0-2568]|6[0259]|5[34]|4[245]|3[0158]|0[259]|8[015-7]|1[03-589]|7[35-8])|7(?:45|8[027]|1[2-6]|3[36]|0[68]|2[1-35])|408|807))',
+    '110' => '(?:8(?:5(?:8[2-468]|6[0-25-7]|5[0589]|4[013689]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|2[0-24])|6(?:97|2[0-2568]|6[0259]|5[34]|4[245]|3[0158]|0[259]|8[015-7]|1[03-589]|7[35-8])|7(?:45|8[027]|1[2-6]|3[36]|0[68]|2[1-35])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|21|98|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|0[1467]|2[02579]|4[24]|7[01578]|5[0-57]|8[0-578]|3[02-5]|1[0-28]|6[02-478])|5(?:4[018]|6[02369]|3[138]|0[125689]|2[248]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
+    '112' => '(?:8(?:6(?:90|6[02-48]|0[1467]|2[02579]|4[24]|7[01578]|5[0-57]|8[0-578]|3[02-5]|1[0-28])|5(?:4[018]|6[02369]|3[138]|0[125689]|2[248]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
     '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[0135]|7[147]|2[0-2468]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|622|711))',
@@ -134,10 +134,10 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|7[0157]|2[0267]|4[08]|1[125]|0[3578])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|8[03]|3[0136-9]|7[1-36]|6[0367]|2[013569]|0[25-8]|5[0-28]|1[1256])|6(?:01|7[02578]|4[04]|6[0168]|1[13-79]|2[13568]|3[01479]|8[0278]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:2[01379]|3[0137-9]|4[02-46-8]|0[2-6]|8[048]|6[03-5]|7[1-39]|1[01356]|5[06-8])|5(?:34|4[04]|0[13-578]|5[59]|2[0-25]|1[02579]|6[0-25-8]|8[0248]|7[267])|4(?:2[0-3]|1[1-9])|7(?:0[17]|1[05])|001))',
+    '141' => '(?:8(?:6(?:3[017-9]|2[01379]|4[02-46-8]|0[2-6]|8[048]|6[03-5]|7[1-39]|1[01356]|5[06-8])|5(?:34|4[04]|0[13-578]|5[59]|2[0-25]|1[02579]|6[0-25-8]|8[0248]|7[267])|4(?:2[0-3]|1[1-9])|7(?:0[17]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)))',
     '143' => '(?:85(?:28|70|5[02578]|3[13589]|0[24578]|8[05]|6[0578]|4[014]|1[145]))',
-    '144' => '(?:8(?:5(?:25|44|5[015]|8[018]|3[0-356]|7[057]|1[01356]|0[56])|6(?:02|11|2[1-3]|5[056]|7[78]|6[01])))',
+    '144' => '(?:8(?:5(?:44|5[015]|8[018]|3[0-356]|7[057]|2[25]|1[01356]|0[56])|6(?:02|11|2[1-3]|5[056]|7[78]|6[01])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:22|31|67|5[158]|8[058]|1[0-25]|7[67]|0[15]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
     '150' => '(?:8(?:5(?:45|5[015]|6[37]|2[25]|8[5-8]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
@@ -201,7 +201,7 @@ our %ZIP_TABLE = (
     '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|3[35]|7[0367]|8[015-9]|1[125]|4[56]))',
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
-    '216' => '(?:85(?:[56]6|01|22|70|1[0-249]))',
+    '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
     '220' => '(?:8(?:5(?:36|58|77|1[015]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:20|53|78|0[149]|1[1-6]|6[08]|8[046])|7(?:11|22|65)|080|173))',
     '221' => '(?:8(?:5(?:[46]0|37|88|1[17]|2[023]|5[08])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:77|3[03]|8[056]|6[1-6]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
@@ -273,7 +273,7 @@ our %ZIP_TABLE = (
     '297' => '(?:(?:8(?:5(?:[01]1|33|67|88|5[58])|6(?:11|22|66))|0(?:19[2-8]|29[28])))',
     '298' => '(?:(?:029[25-7]|8501))',
     '299' => '(?:(?:4(?:39[24-6]|[126]92|49[23])|0(?:29[235-8]|19[2-58])|2(?:[1245]92|79[25])|5(?:29[25]|192)|119[245]))',
-    '300' => '(?:(?:2(?:6(?:86|9[58])|49[2-578]|79[23578]|395|593)|0(?:39[2-8]|19[23]|49[26]|59[35]|[67]92)|1(?:29[24-6]|19[235]|[34]92|696)|8(?:5(?:50|67|88)|6(?:01|19|86))|4(?:19[23]|29[35]|495|598)|3(?:59[258]|29[45])))',
+    '300' => '(?:(?:0(?:3(?:88|9[2-8])|19[23]|49[26]|59[35]|[67]92)|2(?:6(?:86|9[58])|49[2-578]|79[23578]|395|593)|1(?:29[24-6]|19[235]|[34]92|696)|8(?:5(?:50|67|88)|6(?:01|19|86))|4(?:19[23]|29[35]|495|598)|3(?:59[258]|29[45])))',
     '301' => '(?:8(?:6(?:0[12]|1[01])|5(?:55|0[15])))',
     '302' => '(?:(?:85(?:0[12]|8[56])|0198))',
     '303' => '(?:850[13])',
@@ -300,7 +300,7 @@ our %ZIP_TABLE = (
     '324' => '(?:(?:8(?:5(?:01|85|1[06]|5[015])|6(?:25|4[12]))|0(?:59[2-6]|29[23]|69[23]|492)))',
     '325' => '(?:039[23578])',
     '326' => '(?:(?:8(?:5(?:11|20|72|85|5[08]|0[125])|6(?:[01]1|30|86))|039[25]))',
-    '327' => '(?:(?:8(?:5(?:11|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
+    '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|5[0568]|8[568]|0[1-5])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:59[568]|49[28]|69[26]|195)|1(?:19[3-68]|39[235]|292|493)|2(?:19[23]|79[23]|99[23]|292)|4(?:49[23]|392)|3292))',
     '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|6[4-6]|3[156]|2[35]|7[57]|1[0-2]|0[1-37-9]|8[0-3568])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:01|30|77|1[01])|7(?:15|9[67])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:47|8[015]|0[3568]|3[238]|1[0189]|2[29]|7[129]|5[01]|6[56])|6(?:01|69|8[68])|710)))',
@@ -478,7 +478,7 @@ our %ZIP_TABLE = (
     '506' => '(?:(?:8(?:6(?:66|78|0[13]|8[6-8])|5(?:77|85|0[26]|5[05]))|1(?:49[23568]|19[56]|392)|019[24]|2192))',
     '507' => '(?:8(?:5(?:[16]1|33|2[237])|6(?:50|0[1-3578])|70[1-3568]))',
     '508' => '(?:(?:8(?:5(?:[58]5|11|0[0-2])|6(?:[68]6|11))|0(?:292|494)))',
-    '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|19[23]|69[25]|492)|0(?:29[24-8]|19[278]|393|492)|2(?:59[2358]|29[235])|5(?:19[2358]|292|494)|9(?:29[23568]|19[25])|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
+    '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|19[23]|69[25]|492)|0(?:29[24-8]|19[278]|393|492)|5(?:19[23568]|292|494)|2(?:59[2358]|29[235])|9(?:29[23568]|19[25])|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
     '510' => '(?:(?:8(?:5(?:[34]0|5[0257]|0[3-5]|8[058]|1[0-25]|7[57]|2[0258]|6[0-27])|6(?:[23]1|42|66|70|5[15]|1[56]|0[145]))|0(?:29[2-58]|[13]92)|1292))',
     '511' => '(?:(?:8(?:5(?:[67]7|02|33|5[058]|8[58]|1[01])|6(?:[68]6|01|78)|7(?:11|98))|0(?:29[2-68]|19[28]|59[23]|492)|1192))',
     '512' => '(?:85(?:12|38|50))',
@@ -513,7 +513,7 @@ our %ZIP_TABLE = (
     '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|4[0-35-7]|7[12568]|8[1579]|0[1-35689]|1[16-8]|6[368]|3[014578])|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|[58][58]|0[12])|6(?:01|66|8[68])))',
-    '544' => '(?:8(?:5(?:01|55)|666))',
+    '544' => '(?:8(?:5(?:01|55)|6[68]6))',
     '545' => '(?:85(?:[01]1|22|33|45|5[05]|8[56]))',
     '546' => '(?:8501)',
     '547' => '(?:85(?:01|80|1[04]))',
@@ -612,7 +612,7 @@ our %ZIP_TABLE = (
     '648' => '(?:(?:0(?:2(?:8\d|9[2-8])|198|392)|85(?:41|85)))',
     '649' => '(?:(?:6(?:49[2-4]|59[235]|[126]92)|(?:[04]1|35)92|219[2358]|719[245]))',
     '650' => '(?:8(?:5(?:43|1[015]|5[01589]|2[0-258]|6[057]|3[0369]|7[015-7]|8[04-689]|0[1-35])|6(?:[68][06]|7[07])|7(?:87|94)))',
-    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[078]|9[4-7])|49[24])|01(?:7[0-2578]|9[35]|8[1578])|1195))',
+    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[0178]|9[4-7])|49[24])|01(?:7[0-2578]|9[35]|8[1578])|1195))',
     '652' => '(?:85(?:[17]0|01|85|5[05]))',
     '653' => '(?:85(?:70|85))',
     '654' => '(?:(?:85(?:70|85)|019[2358]))',
@@ -737,7 +737,7 @@ our %ZIP_TABLE = (
     '778' => '(?:(?:850[13-7]|0[12]95))',
     '779' => '(?:(?:3(?:39[3-5]|[4-6]95|29[58])|1(?:29[235]|19[58])|4(?:[478]95|19[35])|(?:53|2[13])95|019[2-5]))',
     '780' => '(?:8(?:5(?:4[01458]|0[1-9]|2[0-35-9]|3[02-9]|6[0-25-8]|5[03-689]|1[0-8]|7[0-27])|6(?:7[05-7]|6[0-2568]|8\d|0[125])|787))',
-    '781' => '(?:(?:85(?:21|43|60|88|1[015]|5[1257])|5(?:19[25]|29[25]|79[23]|495)|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
+    '781' => '(?:(?:5(?:19[25]|29[25]|79[23]|495)|85(?:21|43|60|1[015]|5[1257])|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
     '782' => '(?:8502)',
     '783' => '(?:85(?:55|0[125-9]))',
     '784' => '(?:850[135])',
@@ -797,7 +797,7 @@ our %ZIP_TABLE = (
     '838' => '(?:(?:8(?:6(?:[68]6|77|0[12])|5(?:85|1[25]))|1(?:39[78]|79[23]|[56]92)|0(?:19[378]|298)))',
     '839' => '(?:(?:1(?:39[3-6]|49[378]|298)|85(?:40|0[12568])|029[235]))',
     '840' => '(?:(?:8(?:5(?:[246]0|11|5[0-258]|8[058]|0[12]|7[01])|6(?:[01]1|27|66|8[689]))|2(?:19[2357]|295)|0(?:292|598)|1192))',
-    '841' => '(?:8(?:6(?:11|86|0[12])|5(?:[01]1|85)))',
+    '841' => '(?:8(?:5(?:11|85|0[14])|6(?:11|86|0[12])))',
     '842' => '(?:(?:8(?:5(?:85|0[12])|601)|0(?:19[2357]|29[23])))',
     '843' => '(?:(?:8(?:5(?:01|8[58]|5[05])|6(?:39|86))|039[2-4]))',
     '844' => '(?:8(?:6(?:16|25|0[12])|5(?:[58]5|01)))',
@@ -826,11 +826,11 @@ our %ZIP_TABLE = (
     '867' => '(?:85(?:[58]5|01))',
     '868' => '(?:(?:8(?:5(?:55|1[15]|0[1-358])|601)|0(?:59[23578]|39[23]|795)))',
     '869' => '(?:(?:0(?:19[238]|29[235]|49[2-4]|59[238]|696)|2(?:59[2358]|69[2356]|49[23])|1(?:29[2358]|19[23])|5(?:39[23]|498|692)|3(?:296|692)|4292))',
-    '870' => '(?:(?:8(?:5(?:41|0[1-46]|5[158]|1[013]|7[07]|[38][58]|2[13-5]|6[02-4])|6(?:46|58|8[6-8]|1[169]|3[4-6]|7[67]|2[07]|6[05]|0[15]))|0(?:1(?:89|9[2-8])|39[235-8]|[29]92|401)|1(?:19[258]|292)))',
+    '870' => '(?:(?:8(?:5(?:0[1-46]|5[158]|4[14]|1[013]|7[07]|[38][58]|2[13-5]|6[02-4])|6(?:46|58|8[6-8]|1[169]|3[4-6]|7[67]|2[07]|6[05]|0[15]))|0(?:1(?:89|9[2-8])|39[235-8]|[29]92|401)|1(?:19[258]|292)))',
     '871' => '(?:(?:8(?:5(?:21|77|85|5[05]|0[12]|1[01])|6(?:[02]9|42|66|8[68]))|0(?:99[23]|[27]95|192)))',
     '872' => '(?:0592)',
     '873' => '(?:(?:0(?:29[238]|498)|8501))',
-    '874' => '(?:8(?:5(?:[01]1|[67]7|8[58]|5[578])|6(?:11|39|86|6[06])))',
+    '874' => '(?:8(?:5(?:[01]1|[67]7|8[58]|5[578])|6(?:11|39|6[06]|8[68])))',
     '875' => '(?:(?:8(?:6(?:86|1[26])|501)|0292))',
     '876' => '(?:(?:8(?:5(?:55|8[05])|6(?:01|66))|2492))',
     '877' => '(?:(?:8(?:5(?:01|55)|6(?:01|86))|0(?:39[23]|296)|1292))',
